# -*- coding: utf-8 -*-
"""Module containing QSciScintilla-related classes."""

from .sciscintilla import SciScintilla

__all__ = ["SciScintilla"]
